pub enum HandshakeKind {
Full,
FullWithHelloRetryRequest,
Resumed,
}展开描述
描述发生了哪种握手。
变体
Full
完整握手。
This 是 typical TLS connection initiation process when resumption is
not yet unavailable, 并 the initial ClientHello was 已接受 by the server.
FullWithHelloRetryRequest
A full TLS 1.3 handshake, with an extra round-trip 用于 一个 HelloRetryRequest。
此 server can respond with 一个 HelloRetryRequest if the initial ClientHello
is unacceptable 用于 several reasons, the most likely if no supported key
shares were offered by the client.
Resumed
一个會话恢复的握手。
Resumed handshakes involve fewer round trips 并 less cryptography than full ones, but can only happen when the peers have previously done 一个 full handshake together, 并 then remember data about it.
Trait 实现
Sourceimpl Clone for HandshakeKind
impl Clone for HandshakeKind
Sourcefn clone(&self) -> HandshakeKind
fn clone(&self) -> HandshakeKind
返回值的副本。 更多信息
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment 从
source. 更多信息Sourceimpl Debug for HandshakeKind
impl Debug for HandshakeKind
Sourceimpl PartialEq for HandshakeKind
impl PartialEq for HandshakeKind
impl Copy for HandshakeKind
impl StructuralPartialEq for HandshakeKind
自动 Trait 实现
impl Freeze for HandshakeKind
impl RefUnwindSafe for HandshakeKind
impl Send for HandshakeKind
impl Sync for HandshakeKind
impl Unpin for HandshakeKind
impl UnsafeUnpin for HandshakeKind
impl UnwindSafe for HandshakeKind
Blanket 实现
Sourceimpl<T> BorrowMut<T> for Twhere
T: ?Sized,
impl<T> BorrowMut<T> for Twhere
T: ?Sized,
Sourcefn borrow_mut(&mut self) -> &mut T
fn borrow_mut(&mut self) -> &mut T
Mutably borrows 从 an owned value. 更多信息