跳到主要内容

KeyLogFile

结构体 KeyLogFile 

pub struct KeyLogFile(/* private fields */);
展开描述

KeyLog implementation that opens 一个 file whose 名称是 given by the SSLKEYLOGFILE environment variable, 并 writes keys into it.

如果没有设置 SSLKEYLOGFILE,则不会有任何做用。

If such 一个 file cannot be opened, 或 cannot be written then this does nothing but logs errors at warning-level.

实现

Source

impl KeyLogFile

pub fn new() -> Self

Makes 新 KeyLogFile。 此 environment variable is inspected 并 the named file is opened during this 调用。

Trait 实现

Source

impl Debug for KeyLogFile

Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化此值。 更多信息
Source

impl KeyLog for KeyLogFile

Source

fn log(&self, label: &str, client_random: &[u8], secret: &[u8])

Log the given secret. client_random , 用于 session identification. label describes precisely what secret means: 更多信息
Source

fn will_log(&self, _label: &str) -> bool

指明是否会记录标签为 label 的密钥 更多信息

自动 Trait 实现

Blanket 实现

Source

impl<T> Any for T
where T: 'static + ?Sized,

Source

fn type_id(&self) -> TypeId

Gets the TypeId of self. 更多信息
Source

impl<T> Borrow<T> for T
where T: ?Sized,

Source

fn borrow(&self) -> &T

Immutably borrows 从 an owned value. 更多信息
Source

impl<T> BorrowMut<T> for T
where T: ?Sized,

Source

fn borrow_mut(&mut self) -> &mut T

Mutably borrows 从 an owned value. 更多信息
Source

impl<T> From<T> for T

Source

fn from(t: T) -> T

原样返回传入的参数。

Source

impl<T, U> Into<U> for T
where U: From<T>,

Source

fn into(self) -> U

Calls U::从(self)

That is, this conversion is whatever the implementation of From<T> 用于 U 的实现方式。

Source

impl<T, U> TryFrom<U> for T
where U: Into<T>,

Source

type Error = Infallible

转换出错时返回的类型。
Source

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行转换。
Source

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

Source

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
Source

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行转换。